BlobReadRequest class

Request to read a blob's bytes.

Constructors

BlobReadRequest({required String collection, required String id, int? rangeStart, int? rangeEnd})

Properties

collection → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
rangeEnd → int?
Optional exclusive byte range end.
final
rangeStart → int?
Optional inclusive byte range start.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited